@@ -43,6 +43,12 @@ bitflags! {
         const GUILD_INTEGRATIONS_UPDATE = 1 << 13;
         /// A guild has been updated.
         const GUILD_UPDATE = 1 << 14;
+        /// A guild integration was created.
+        const INTEGRATION_CREATE = 1 << 60;
+        /// A guild integration was deleted.
+        const INTEGRATION_DELETE = 1 << 61;
+        /// A guild integration was updated.
+        const INTEGRATION_UPDATE = 1 << 62;
         /// Invite for a channel has been created.
         const INVITE_CREATE = 1 << 46;
         /// Invite for a channel has been deleted.
@@ -105,6 +111,12 @@ bitflags! {
         const SHARD_RECONNECTING = 1 << 37;
         /// Shard is resuming a session with the gateway.
         const SHARD_RESUMING = 1 << 38;
+        /// Stage instance was created in a stage channel.
+        const STAGE_INSTANCE_CREATE = 1 << 57;
+        /// Stage instance was deleted in a stage channel.
+        const STAGE_INSTANCE_DELETE = 1 << 58;
+        /// Stage instance was updated in a stage channel.
+        const STAGE_INSTANCE_UPDATE = 1 << 59;
         /// User has begun typing in a channel.
         const TYPING_START = 1 << 39;
         /// Guild is unavailable, potentially due to an outage.
@@ -140,6 +152,9 @@ impl From<EventType> for EventTypeFlags {
             EventType::GuildEmojisUpdate => EventTypeFlags::GUILD_EMOJIS_UPDATE,
             EventType::GuildIntegrationsUpdate => EventTypeFlags::GUILD_INTEGRATIONS_UPDATE,
             EventType::GuildUpdate => EventTypeFlags::GUILD_UPDATE,
+            EventType::IntegrationCreate => EventTypeFlags::INTEGRATION_CREATE,
+            EventType::IntegrationDelete => EventTypeFlags::INTEGRATION_DELETE,
+            EventType::IntegrationUpdate => EventTypeFlags::INTEGRATION_UPDATE,
             EventType::InviteCreate => EventTypeFlags::INVITE_CREATE,
             EventType::InviteDelete => EventTypeFlags::INVITE_DELETE,
             EventType::MemberAdd => EventTypeFlags::MEMBER_ADD,
@@ -168,6 +183,9 @@ impl From<EventType> for EventTypeFlags {
             EventType::ShardReconnecting => EventTypeFlags::SHARD_RECONNECTING,
             EventType::ShardPayload => EventTypeFlags::SHARD_PAYLOAD,
             EventType::ShardResuming => EventTypeFlags::SHARD_RESUMING,
+            EventType::StageInstanceCreate => EventTypeFlags::STAGE_INSTANCE_CREATE,
+            EventType::StageInstanceDelete => EventTypeFlags::STAGE_INSTANCE_DELETE,
+            EventType::StageInstanceUpdate => EventTypeFlags::STAGE_INSTANCE_UPDATE,
             EventType::TypingStart => EventTypeFlags::TYPING_START,
             EventType::UnavailableGuild => EventTypeFlags::UNAVAILABLE_GUILD,
             EventType::UserUpdate => EventTypeFlags::USER_UPDATE,
